summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
authorDimitri van Heesch <dimitri@stack.nl>2016-05-25 09:23:47 (GMT)
committerDimitri van Heesch <dimitri@stack.nl>2016-05-25 09:23:47 (GMT)
commitb00761b30a1d399f95adfe823937c05a64476155 (patch)
tree5b8325543bb56cde350c9cbe0174c05d81743a59 /src
parent54ccd9f2b1143b89ac5088e5c1d3834e005a4b35 (diff)
downloadDoxygen-b00761b30a1d399f95adfe823937c05a64476155.zip
Doxygen-b00761b30a1d399f95adfe823937c05a64476155.tar.gz
Doxygen-b00761b30a1d399f95adfe823937c05a64476155.tar.bz2
Bug 766698 - VHDL: missing last sign in html documentation of constant declaration
Diffstat (limited to 'src')
-rw-r--r--src/doxygen.cpp5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/doxygen.cpp b/src/doxygen.cpp
index e1f8440..b67ce18 100644
--- a/src/doxygen.cpp
+++ b/src/doxygen.cpp
@@ -2654,7 +2654,10 @@ static MemberDef *addVariableToFile(
*/
static int findFunctionPtr(const QCString &type,int lang, int *pLength=0)
{
- if (lang == SrcLangExt_Fortran) return -1; // Fortran does not have function pointers
+ if (lang == SrcLangExt_Fortran || lang == SrcLangExt_VHDL)
+ {
+ return -1; // Fortran and VHDL do not have function pointers
+ }
static const QRegExp re("([^)]*[\\*\\^][^)]*)");
int i=-1,l;
int bb=type.find('<');